#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=lopnor3.22_sel2.ps
projection=-JM16.0c+
region=-R88.3/88.6/41.6/41.9
gmt psbasemap $region $projection -Bxa0.2f0.1 -Bya0.2f0.1 -BWeSn+t'Base Map lopnor3.22' -K > $psfile
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut tables/gmt/dem/GLOBE/g10g.grd -Gmloc.grd $region -fg
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd
gmt pscoast $projection $region -Df -Ia,blue -Wblue -O -K >> $psfile
# Event numbers
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    41.695    88.354
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    41.738    88.373
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    41.718    88.353
END
# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    41.741    88.434
    41.740    88.434
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    41.684    88.218
    41.695    88.354
END
gmt psxy -: -R $projection -Wthin,red -O -K << END >> $psfile
    41.740    88.434
    41.695    88.354
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    41.782    88.451
    41.783    88.453
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    41.681    88.303
    41.738    88.373
END
gmt psxy -: -R $projection -Wthin,red -O -K << END >> $psfile
    41.783    88.453
    41.738    88.373
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    41.763    88.433
    41.764    88.434
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    41.701    88.319
    41.718    88.353
END
gmt psxy -: -R $projection -Wthin,red -O -K << END >> $psfile
    41.764    88.434
    41.718    88.353
END
# Calibration locations marked by a red cross
gmt psxy -: -R $projection -Sx -Wthick,red -O -K << END >> $psfile
    41.709    88.390     0.200
    41.541    88.755     0.200
    41.541    88.728     0.200
    41.580    88.725     0.200
    41.708    88.386     0.200
    41.556    88.743     0.200
    41.576    88.713     0.200
    41.527    88.736     0.200
    41.534    88.767     0.200
    41.716    88.378     0.200
    41.528    88.712     0.200
    41.574    88.719     0.200
    41.551    88.750     0.200
    41.541    88.752     0.200
    41.580    88.689     0.200
END
# Calibration location confidence ellipses
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    41.709    88.390     0.000     2.000     2.000
    41.541    88.755     0.000     2.000     2.000
    41.541    88.728     0.000     2.000     2.000
    41.580    88.725     0.000     2.000     2.000
    41.708    88.386     0.000     2.000     2.000
    41.556    88.743     0.000     2.000     2.000
    41.576    88.713     0.000     2.000     2.000
    41.527    88.736     0.000     2.000     2.000
    41.534    88.767     0.000     2.000     2.000
    41.716    88.378     0.000     2.000     2.000
    41.528    88.712     0.000     2.000     2.000
    41.574    88.719     0.000     2.000     2.000
    41.551    88.750     0.000     2.000     2.000
    41.541    88.752     0.000     2.000     2.000
    41.580    88.689     0.000     2.000     2.000
END
# Residual calibration shift vectors
gmt psxy -: -R $projection -Wthick,blue -O -K << END >> $psfile
    41.709    88.390
    41.695    88.354
END
gmt psxy -: -R $projection -Wthick,blue -O -K << END >> $psfile
    41.708    88.386
    41.738    88.373
END
gmt psxy -: -R $projection -Wthick,blue -O -K << END >> $psfile
    41.716    88.378
    41.718    88.353
END
# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    41.695    88.354   -62.033     5.321     6.119
    41.738    88.373    -5.978     3.797     4.824
    41.718    88.353   -62.948     1.791     2.413
END
# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    41.649    88.326   -62.687     2.508     2.820
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    41.649    88.348   Hypocentroid
END
# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    41.649    88.326     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    41.649    88.326     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    41.604    88.326   5 km
END
